@@ -100,7 +100,15 @@ public class BaseGuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisi
                                                       columnsPage,
                                                       saveAndRenameCommandBuilder,
                                                       alertsButtonMenuItemBuilder,
-                                                      downloadMenuItem) {
+                                                      downloadMenuItemBuilder,
+                                                      editorSearchIndex,
+                                                      searchBarComponent,
+                                                      searchableElementFactory,
+                                                      null) {
+            {
+                promises = BaseGuidedDecisionTableEditorPresenterTest.this.promises;
+                projectController = BaseGuidedDecisionTableEditorPresenterTest.this.projectController;
+            }
 
             @Override
             protected Command getSaveAndRenameCommand() {
@@ -121,6 +129,11 @@ public class BaseGuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisi
                times(1)).setModellerView(eq(modellerView));
     }
 
+    @Test
+    public void testGetModellerView() {
+        assertEquals(modellerView, presenter.getModellerView());
+    }
+
     @Test
     public void checkOnStartup() {
         final ObservablePath path = mock(ObservablePath.class);
@@ -293,8 +306,9 @@ public class BaseGuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisi
 
         verify(presenter,
                never()).activateDocument(any(GuidedDecisionTableView.Presenter.class));
-        assertTrue(getMenuState(presenter.getMenus(),
-                                MenuItems.VALIDATE));
+
+        presenter.getMenus(menus -> assertTrue(getMenuState(menus,
+                                                            MenuItems.VALIDATE)));
     }
 
     private boolean getMenuState(final Menus menus,
@@ -324,8 +338,9 @@ public class BaseGuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisi
                times(1)).activateDocument(any(GuidedDecisionTableView.Presenter.class));
         verify(radarMenuItem,
                atLeast(1)).setEnabled(eq(true));
-        assertTrue(getMenuState(presenter.getMenus(),
-                                MenuItems.VALIDATE));
+
+        presenter.getMenus(menus -> assertTrue(getMenuState(menus,
+                                                            MenuItems.VALIDATE)));
     }
 
     @Test
@@ -345,8 +360,8 @@ public class BaseGuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisi
 
         verify(presenter,
                never()).activateDocument(any(GuidedDecisionTableView.Presenter.class));
-        assertTrue(getMenuState(presenter.getMenus(),
-                                MenuItems.VALIDATE));
+        presenter.getMenus(menus -> assertTrue(getMenuState(menus,
+                                                            MenuItems.VALIDATE)));
     }
 
     @Test
@@ -357,8 +372,8 @@ public class BaseGuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisi
 
         verify(presenter,
                never()).activateDocument(any(GuidedDecisionTableView.Presenter.class));
-        assertFalse(getMenuState(presenter.getMenus(),
-                                 MenuItems.VALIDATE));
+        presenter.getMenus(menus -> assertTrue(getMenuState(menus,
+                                                            MenuItems.VALIDATE)));
     }
 
     @Test
