@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,6 +21,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 
+import org.drools.workbench.models.datamodel.rule.Attribute;
 import org.drools.workbench.models.guided.dtable.shared.model.AttributeCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumnFieldDiff;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.BaseSingletonDOMElementUiColumn;
@@ -28,9 +29,8 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.Bo
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.IntegerUiColumn;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.SalienceUiColumn;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.StringUiColumn;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.impl.BaseSynchronizer.MoveColumnToMetaData;
-import org.drools.workbench.screens.guided.rule.client.editor.RuleAttributeWidget;
 import org.junit.Test;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
@@ -46,36 +46,36 @@ import static org.mockito.Mockito.when;
 public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
 
     @Test
-    public void testAppend() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testAppend() throws VetoException {
         final AttributeCol52 column = new AttributeCol52();
-        column.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column.setAttribute(Attribute.SALIENCE.getAttributeName());
 
         modelSynchronizer.appendColumn(column);
 
         assertEquals(1,
                      model.getAttributeCols().size());
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      model.getAttributeCols().get(0).getAttribute());
 
         assertEquals(3,
                      uiModel.getColumns().size());
         assertTrue(uiModel.getColumns().get(2) instanceof IntegerUiColumn);
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
         assertEquals(true,
                      ((BaseSingletonDOMElementUiColumn) uiModel.getColumns().get(2)).isEditable());
     }
 
     @Test
-    public void testUpdate1() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate1() throws VetoException {
         final AttributeCol52 column = spy(new AttributeCol52());
-        column.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column.setAttribute(Attribute.SALIENCE.getAttributeName());
 
         modelSynchronizer.appendColumn(column);
 
         final AttributeCol52 edited = new AttributeCol52();
         edited.setWidth(column.getWidth());
-        edited.setAttribute(RuleAttributeWidget.ENABLED_ATTR);
+        edited.setAttribute(Attribute.ENABLED.getAttributeName());
 
         List<BaseColumnFieldDiff> diffs = modelSynchronizer.updateColumn(column,
                                                                          edited);
@@ -85,26 +85,26 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
 
         assertEquals(1,
                      model.getAttributeCols().size());
-        assertEquals(RuleAttributeWidget.ENABLED_ATTR,
+        assertEquals(Attribute.ENABLED.getAttributeName(),
                      model.getAttributeCols().get(0).getAttribute());
 
         assertEquals(3,
                      uiModel.getColumns().size());
         assertTrue(uiModel.getColumns().get(2) instanceof BooleanUiColumn);
-        assertEquals(RuleAttributeWidget.ENABLED_ATTR,
+        assertEquals(Attribute.ENABLED.getAttributeName(),
                      uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
     }
 
     @Test
-    public void testUpdate2() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate2() throws VetoException {
         final AttributeCol52 column = spy(new AttributeCol52());
-        column.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column.setAttribute(Attribute.SALIENCE.getAttributeName());
 
         modelSynchronizer.appendColumn(column);
 
         final AttributeCol52 edited = new AttributeCol52();
         edited.setWidth(column.getWidth());
-        edited.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        edited.setAttribute(Attribute.SALIENCE.getAttributeName());
         edited.setHideColumn(true);
 
         List<BaseColumnFieldDiff> diffs = modelSynchronizer.updateColumn(column,
@@ -115,30 +115,30 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
 
         assertEquals(1,
                      model.getAttributeCols().size());
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      model.getAttributeCols().get(0).getAttribute());
 
         assertEquals(3,
                      uiModel.getColumns().size());
         assertTrue(uiModel.getColumns().get(2) instanceof IntegerUiColumn);
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
         assertEquals(false,
                      uiModel.getColumns().get(2).isVisible());
     }
 
     @Test
-    public void testUpdateSalienceRowNumber() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdateSalienceRowNumber() throws VetoException {
         modelSynchronizer.appendRow();
         modelSynchronizer.appendRow();
 
         final AttributeCol52 column = new AttributeCol52();
-        column.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column.setAttribute(Attribute.SALIENCE.getAttributeName());
 
         modelSynchronizer.appendColumn(column);
 
         final AttributeCol52 edited1 = new AttributeCol52();
-        edited1.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        edited1.setAttribute(Attribute.SALIENCE.getAttributeName());
         edited1.setUseRowNumber(true);
 
         modelSynchronizer.updateColumn(column,
@@ -146,7 +146,7 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
 
         assertEquals(1,
                      model.getAttributeCols().size());
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      model.getAttributeCols().get(0).getAttribute());
         assertEquals(1,
                      model.getData().get(0).get(2).getNumericValue());
@@ -156,7 +156,7 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(3,
                      uiModel.getColumns().size());
         assertTrue(uiModel.getColumns().get(2) instanceof SalienceUiColumn);
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
         assertEquals(true,
                      ((SalienceUiColumn) uiModel.getColumns().get(2)).isUseRowNumber());
@@ -166,7 +166,7 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModel.getRow(1).getCells().get(2).getValue().getValue());
 
         final AttributeCol52 edited2 = new AttributeCol52();
-        edited2.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        edited2.setAttribute(Attribute.SALIENCE.getAttributeName());
         edited2.setUseRowNumber(true);
         edited2.setReverseOrder(true);
 
@@ -175,7 +175,7 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
 
         assertEquals(1,
                      model.getAttributeCols().size());
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      model.getAttributeCols().get(0).getAttribute());
         assertEquals(2,
                      model.getData().get(0).get(2).getNumericValue());
@@ -185,7 +185,7 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(3,
                      uiModel.getColumns().size());
         assertTrue(uiModel.getColumns().get(2) instanceof SalienceUiColumn);
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
         assertEquals(true,
                      ((SalienceUiColumn) uiModel.getColumns().get(2)).isUseRowNumber());
@@ -196,9 +196,9 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testDelete() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testDelete() throws VetoException {
         final AttributeCol52 column = new AttributeCol52();
-        column.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column.setAttribute(Attribute.SALIENCE.getAttributeName());
 
         modelSynchronizer.appendColumn(column);
 
@@ -215,22 +215,22 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnTo_MoveLeft() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_MoveLeft() throws VetoException {
         final AttributeCol52 column1 = new AttributeCol52();
-        column1.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column1.setAttribute(Attribute.SALIENCE.getAttributeName());
         final AttributeCol52 column2 = new AttributeCol52();
-        column2.setAttribute(RuleAttributeWidget.AGENDA_GROUP_ATTR);
+        column2.setAttribute(Attribute.AGENDA_GROUP.getAttributeName());
 
         modelSynchronizer.appendColumn(column1);
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<Integer>(1));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("smurf"));
+        uiModel.setCellValue(0,
+                             2,
+                             new BaseGridCellValue<Integer>(1));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("smurf"));
 
         assertEquals(2,
                      model.getAttributeCols().size());
@@ -247,9 +247,9 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModel.getColumns().size());
         final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
         final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
-        assertEquals(RuleAttributeWidget.AGENDA_GROUP_ATTR,
+        assertEquals(Attribute.AGENDA_GROUP.getAttributeName(),
                      uiModelColumn2_1.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
@@ -280,9 +280,9 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModel.getColumns().size());
         final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
         final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        assertEquals(RuleAttributeWidget.AGENDA_GROUP_ATTR,
+        assertEquals(Attribute.AGENDA_GROUP.getAttributeName(),
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModelColumn2_2.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof IntegerUiColumn);
@@ -297,22 +297,22 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnTo_MoveRight() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_MoveRight() throws VetoException {
         final AttributeCol52 column1 = new AttributeCol52();
-        column1.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column1.setAttribute(Attribute.SALIENCE.getAttributeName());
         final AttributeCol52 column2 = new AttributeCol52();
-        column2.setAttribute(RuleAttributeWidget.AGENDA_GROUP_ATTR);
+        column2.setAttribute(Attribute.AGENDA_GROUP.getAttributeName());
 
         modelSynchronizer.appendColumn(column1);
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<Integer>(1));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("smurf"));
+        uiModel.setCellValue(0,
+                             2,
+                             new BaseGridCellValue<Integer>(1));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("smurf"));
 
         assertEquals(2,
                      model.getAttributeCols().size());
@@ -329,9 +329,9 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModel.getColumns().size());
         final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
         final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
-        assertEquals(RuleAttributeWidget.AGENDA_GROUP_ATTR,
+        assertEquals(Attribute.AGENDA_GROUP.getAttributeName(),
                      uiModelColumn2_1.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
@@ -362,9 +362,9 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModel.getColumns().size());
         final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
         final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        assertEquals(RuleAttributeWidget.AGENDA_GROUP_ATTR,
+        assertEquals(Attribute.AGENDA_GROUP.getAttributeName(),
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModelColumn2_2.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof IntegerUiColumn);
@@ -379,22 +379,22 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnTo_OutOfBounds() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_OutOfBounds() throws VetoException {
         final AttributeCol52 column1 = new AttributeCol52();
-        column1.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column1.setAttribute(Attribute.SALIENCE.getAttributeName());
         final AttributeCol52 column2 = new AttributeCol52();
-        column2.setAttribute(RuleAttributeWidget.AGENDA_GROUP_ATTR);
+        column2.setAttribute(Attribute.AGENDA_GROUP.getAttributeName());
 
         modelSynchronizer.appendColumn(column1);
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<Integer>(1));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("smurf"));
+        uiModel.setCellValue(0,
+                             2,
+                             new BaseGridCellValue<Integer>(1));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("smurf"));
 
         assertEquals(2,
                      model.getAttributeCols().size());
@@ -411,9 +411,9 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModel.getColumns().size());
         final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
         final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
-        assertEquals(RuleAttributeWidget.AGENDA_GROUP_ATTR,
+        assertEquals(Attribute.AGENDA_GROUP.getAttributeName(),
                      uiModelColumn2_1.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
@@ -444,9 +444,9 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModel.getColumns().size());
         final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
         final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
-        assertEquals(RuleAttributeWidget.AGENDA_GROUP_ATTR,
+        assertEquals(Attribute.AGENDA_GROUP.getAttributeName(),
                      uiModelColumn2_2.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_2 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_2 instanceof StringUiColumn);
@@ -461,28 +461,28 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnsTo_MoveLeft() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnsTo_MoveLeft() throws VetoException {
         final AttributeCol52 column1 = new AttributeCol52();
-        column1.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column1.setAttribute(Attribute.SALIENCE.getAttributeName());
         final AttributeCol52 column2 = new AttributeCol52();
-        column2.setAttribute(RuleAttributeWidget.AGENDA_GROUP_ATTR);
+        column2.setAttribute(Attribute.AGENDA_GROUP.getAttributeName());
         final AttributeCol52 column3 = new AttributeCol52();
-        column3.setAttribute(RuleAttributeWidget.AUTO_FOCUS_ATTR);
+        column3.setAttribute(Attribute.AUTO_FOCUS.getAttributeName());
 
         modelSynchronizer.appendColumn(column1);
         modelSynchronizer.appendColumn(column2);
         modelSynchronizer.appendColumn(column3);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<Integer>(1));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("smurf"));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<Boolean>(true));
+        uiModel.setCellValue(0,
+                             2,
+                             new BaseGridCellValue<Integer>(1));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("smurf"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<Boolean>(true));
 
         final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
         final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
@@ -515,28 +515,28 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnsTo_MoveRight() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnsTo_MoveRight() throws VetoException {
         final AttributeCol52 column1 = new AttributeCol52();
-        column1.setAttribute(RuleAttributeWidget.SALIENCE_ATTR);
+        column1.setAttribute(Attribute.SALIENCE.getAttributeName());
         final AttributeCol52 column2 = new AttributeCol52();
-        column2.setAttribute(RuleAttributeWidget.AGENDA_GROUP_ATTR);
+        column2.setAttribute(Attribute.AGENDA_GROUP.getAttributeName());
         final AttributeCol52 column3 = new AttributeCol52();
-        column3.setAttribute(RuleAttributeWidget.AUTO_FOCUS_ATTR);
+        column3.setAttribute(Attribute.AUTO_FOCUS.getAttributeName());
 
         modelSynchronizer.appendColumn(column1);
         modelSynchronizer.appendColumn(column2);
         modelSynchronizer.appendColumn(column3);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<Integer>(1));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("smurf"));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<Boolean>(true));
+        uiModel.setCellValue(0,
+                             2,
+                             new BaseGridCellValue<Integer>(1));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("smurf"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<Boolean>(true));
 
         final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
         final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
@@ -568,14 +568,14 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void checkHandlesMoveColumnsToWithEmptyMetadata() throws ModelSynchronizer.MoveColumnVetoException {
+    public void checkHandlesMoveColumnsToWithEmptyMetadata() throws VetoException {
         final AttributeColumnSynchronizer synchronizer = new AttributeColumnSynchronizer();
 
         assertFalse(synchronizer.handlesMoveColumnsTo(Collections.emptyList()));
     }
 
     @Test
-    public void checkHandlesMoveColumnsToWithMultipleMetadata() throws ModelSynchronizer.MoveColumnVetoException {
+    public void checkHandlesMoveColumnsToWithMultipleMetadata() throws VetoException {
         final MoveColumnToMetaData md0 = mock(MoveColumnToMetaData.class);
         final MoveColumnToMetaData md1 = mock(MoveColumnToMetaData.class);
         final AttributeColumnSynchronizer synchronizer = new AttributeColumnSynchronizer();
@@ -587,7 +587,7 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void checkHandlesMoveColumnsToWithSingleMetadata() throws ModelSynchronizer.MoveColumnVetoException {
+    public void checkHandlesMoveColumnsToWithSingleMetadata() throws VetoException {
         final MoveColumnToMetaData md0 = mock(MoveColumnToMetaData.class);
         final AttributeColumnSynchronizer synchronizer = new AttributeColumnSynchronizer();
         when(md0.getColumn()).thenReturn(mock(AttributeCol52.class));
@@ -618,11 +618,11 @@ public class AttributeColumnSynchronizerTest extends BaseSynchronizerTest {
 
         assertEquals(5,
                      uiModel.getColumns().size());
-        assertEquals(RuleAttributeWidget.SALIENCE_ATTR,
+        assertEquals(Attribute.SALIENCE.getAttributeName(),
                      uiModelColumn1.getHeaderMetaData().get(0).getTitle());
-        assertEquals(RuleAttributeWidget.AGENDA_GROUP_ATTR,
+        assertEquals(Attribute.AGENDA_GROUP.getAttributeName(),
                      uiModelColumn2.getHeaderMetaData().get(0).getTitle());
-        assertEquals(RuleAttributeWidget.AUTO_FOCUS_ATTR,
+        assertEquals(Attribute.AUTO_FOCUS.getAttributeName(),
                      uiModelColumn3.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2 instanceof StringUiColumn);
