@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,7 +18,7 @@ package org.drools.workbench.screens.guided.dtable.client.widget.table.utilities
 import java.util.Arrays;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.drools.workbench.models.datamodel.oracle.DataType;
+import org.assertj.core.api.Assertions;
 import org.drools.workbench.models.datamodel.rule.BaseSingleFieldConstraint;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionInsertFactCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionSetFieldCol52;
@@ -30,13 +30,19 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.co
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.soup.project.datamodel.oracle.DataType;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.mockito.Mock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Mockito.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class ColumnUtilitiesTest {
@@ -135,14 +141,9 @@ public class ColumnUtilitiesTest {
     public void testGetValueConditionColumn() throws Exception {
         column.setFactField(FIELD_NAME);
         column.setFieldType(DataType.TYPE_NUMERIC_INTEGER);
-        column.setValueList("a,1,1.1, ,-1");
-        String[] valueList = utilities.getValueList(column);
-        assertEquals(2,
-                     valueList.length);
-        assertEquals("1",
-                     valueList[0]);
-        assertEquals("-1",
-                     valueList[1]);
+        column.setValueList("a,1,1.1, ,-1, 123,456 , -789 ");
+        final String[] valueList = utilities.getValueList(column);
+        Assertions.assertThat(valueList).containsExactly("1", "-1", "123", "456", "-789");
     }
 
     @Test
@@ -154,17 +155,12 @@ public class ColumnUtilitiesTest {
         final ActionSetFieldCol52 column = new ActionSetFieldCol52();
         column.setFactField(FIELD_NAME);
         column.setBoundName("$a");
-        column.setValueList("a,1,1.1, ,-1");
+        column.setValueList("a,1,1.1, ,-1, 123,456 , -789 ");
         when(oracle.getFieldType(FACT_TYPE,
                                  FIELD_NAME)).thenReturn("Integer");
 
-        String[] valueList = utilities.getValueList(column);
-        assertEquals(2,
-                     valueList.length);
-        assertEquals("1",
-                     valueList[0]);
-        assertEquals("-1",
-                     valueList[1]);
+        final String[] valueList = utilities.getValueList(column);
+        Assertions.assertThat(valueList).containsExactly("1", "-1", "123", "456", "-789");
     }
 
     @Test
@@ -172,17 +168,12 @@ public class ColumnUtilitiesTest {
         final ActionInsertFactCol52 column = new ActionInsertFactCol52();
         column.setFactField(FIELD_NAME);
         column.setFactType(FACT_TYPE);
-        column.setValueList("a,1,1.1, ,-1");
+        column.setValueList("a,1,1.1, ,-1, 123,456 , -789 ");
         when(oracle.getFieldType(FACT_TYPE,
                                  FIELD_NAME)).thenReturn(DataType.TYPE_NUMERIC_INTEGER);
 
-        String[] valueList = utilities.getValueList(column);
-        assertEquals(2,
-                     valueList.length);
-        assertEquals("1",
-                     valueList[0]);
-        assertEquals("-1",
-                     valueList[1]);
+        final String[] valueList = utilities.getValueList(column);
+        Assertions.assertThat(valueList).containsExactly("1", "-1", "123", "456", "-789");
     }
 
     @Test
