@@ -16,25 +16,24 @@
 
 package org.drools.workbench.screens.scenariosimulation.client.models;
 
-import java.util.ArrayList;
 import java.util.List;
 import java.util.Optional;
 import java.util.function.Supplier;
 import java.util.stream.IntStream;
 
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
-import junit.framework.TestCase;
+import org.drools.scenariosimulation.api.model.ExpressionIdentifier;
+import org.drools.scenariosimulation.api.model.FactIdentifier;
+import org.drools.scenariosimulation.api.model.FactMapping;
+import org.drools.scenariosimulation.api.model.FactMappingValue;
+import org.drools.scenariosimulation.api.model.FactMappingValueStatus;
+import org.drools.scenariosimulation.api.model.Scenario;
 import org.drools.workbench.screens.scenariosimulation.client.AbstractScenarioSimulationTest;
-import org.drools.workbench.screens.scenariosimulation.client.events.ReloadRightPanelEvent;
+import org.drools.workbench.screens.scenariosimulation.client.events.ReloadTestToolsEvent;
 import org.drools.workbench.screens.scenariosimulation.client.metadata.ScenarioHeaderMetaData;
 import org.drools.workbench.screens.scenariosimulation.client.values.ScenarioGridCellValue;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridCell;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridColumn;
-import org.drools.workbench.screens.scenariosimulation.model.ExpressionIdentifier;
-import org.drools.workbench.screens.scenariosimulation.model.FactIdentifier;
-import org.drools.workbench.screens.scenariosimulation.model.FactMapping;
-import org.drools.workbench.screens.scenariosimulation.model.FactMappingValue;
-import org.drools.workbench.screens.scenariosimulation.model.Scenario;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -42,19 +41,37 @@ import org.mockito.Mock;
 import org.uberfire.ext.wires.core.grids.client.model.GridCell;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
-import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.CLASS_NAME;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.COLUMN_INDEX;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.COLUMN_NUMBER;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.FULL_CLASS_NAME;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.GRID_CELL_TEXT;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.GRID_COLUMN_GROUP;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.GRID_COLUMN_ID;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.GRID_COLUMN_TITLE;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.GRID_PROPERTY_TITLE;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.GRID_ROWS;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.HEADER_META_DATA;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.MULTIPART_VALUE;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.MULTIPART_VALUE_ELEMENTS;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.ROW_COUNT;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.ROW_INDEX;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.VALUE_CLASS_NAME;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyDouble;
 import static org.mockito.Matchers.anyInt;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.isA;
 import static org.mockito.Mockito.atLeast;
+import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
@@ -89,75 +106,51 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
     @Mock
     private Scenario scenarioMock;
 
-    private List<GridColumn.HeaderMetaData> headerMetaDataList = new ArrayList<>();
-
-    private List<GridRow> gridRows = new ArrayList<>();
-
     private Supplier<GridCell<?>> gridCellSupplier;
 
-    private final String GRID_COLUMN_TITLE = "GRID_COLUMN_TITLE";
-    private final String GRID_PROPERTY_TITLE = "GRID_PROPERTY_TITLE";
-    private final String GRID_COLUMN_GROUP = "GIVEN";
-    private final String GRID_COLUMN_ID = "GRID_COLUMN_ID";
-    private final String GRID_CELL_TEXT = "GRID_CELL_TEXT";
-    private final String FULL_PACKAGE = "test.scesim";
-    private final String VALUE = "VALUE";
-    private final String VALUE_CLASS_NAME = String.class.getName();
-    private final int ROW_COUNT = 4;
-    private final int ROW_INDEX = 3;
-
     @Before
     public void setup() {
         super.setup();
-        headerMetaDataList.add(groupHeaderMetaDataMock);
-        headerMetaDataList.add(informationHeaderMetaDataMock);
-        headerMetaDataList.add(propertyHeaderMetaDataMock);
+        HEADER_META_DATA.add(groupHeaderMetaDataMock);
+        HEADER_META_DATA.add(informationHeaderMetaDataMock);
+        HEADER_META_DATA.add(propertyHeaderMetaDataMock);
 
         doReturn(gridCellValueMock).when(gridCellMock).getValue();
 
         when(informationHeaderMetaDataMock.getMetadataType()).thenReturn(ScenarioHeaderMetaData.MetadataType.INSTANCE);
-        when(informationHeaderMetaDataMock.isInstanceHeader()).thenReturn(true);
-        when(informationHeaderMetaDataMock.isPropertyHeader()).thenReturn(false);
         when(informationHeaderMetaDataMock.getTitle()).thenReturn(GRID_COLUMN_TITLE);
         when(informationHeaderMetaDataMock.getColumnGroup()).thenReturn(GRID_COLUMN_GROUP);
         when(informationHeaderMetaDataMock.getColumnId()).thenReturn(GRID_COLUMN_ID);
-
-        when(propertyHeaderMetaDataMock.getMetadataType()).thenReturn(ScenarioHeaderMetaData.MetadataType.PROPERTY);
-        when(propertyHeaderMetaDataMock.isInstanceHeader()).thenReturn(false);
-        when(propertyHeaderMetaDataMock.isPropertyHeader()).thenReturn(true);
-        when(propertyHeaderMetaDataMock.getTitle()).thenReturn(GRID_PROPERTY_TITLE);
-        when(propertyHeaderMetaDataMock.getColumnGroup()).thenReturn(GRID_COLUMN_GROUP);
-        when(propertyHeaderMetaDataMock.getColumnId()).thenReturn(GRID_COLUMN_ID);
-
         when(indexHeaderMetaDataMock.getTitle()).thenReturn(ExpressionIdentifier.INDEX.getName());
         when(scenarioIndexGridColumnMock.getInformationHeaderMetaData()).thenReturn(indexHeaderMetaDataMock);
 
-        when(gridColumnMock.getHeaderMetaData()).thenReturn(headerMetaDataList);
-        
+        when(gridColumnMock.getHeaderMetaData()).thenReturn(HEADER_META_DATA);
+
         when(gridCellMock.getValue()).thenReturn(gridCellValueMock);
         when(gridCellValueMock.getValue()).thenReturn(GRID_CELL_TEXT);
 
         when(scenarioMock.getUnmodifiableFactMappingValues()).thenReturn(factMappingValuesLocal);
-
+        GRID_ROWS.clear();
         IntStream.range(0, ROW_COUNT).forEach(rowIndex -> {
             when(simulationMock.addScenario(rowIndex)).thenReturn(scenarioMock);
             when(simulationMock.getScenarioByIndex(rowIndex)).thenReturn(scenarioMock);
             when(simulationMock.cloneScenario(rowIndex, rowIndex + 1)).thenReturn(scenarioMock);
-            gridRows.add(gridRowMock);
+            GRID_ROWS.add(gridRowMock);
         });
         when(simulationMock.addScenario(ROW_COUNT)).thenReturn(scenarioMock);
         when(simulationMock.getScenarioByIndex(ROW_COUNT)).thenReturn(scenarioMock);
         when(simulationMock.cloneScenario(ROW_COUNT, ROW_COUNT + 1)).thenReturn(scenarioMock);
 
         when(scenarioMock.getFactMappingValue(any(), any())).thenReturn(Optional.of(factMappingValueMock));
-        when(factMappingValueMock.isError()).thenReturn(true);
+        when(scenarioMock.getFactMappingValue(isA(FactMapping.class))).thenReturn(Optional.of(factMappingValueMock));
+        when(factMappingValueMock.getStatus()).thenReturn(FactMappingValueStatus.FAILED_WITH_ERROR);
 
         gridCellSupplier = () -> gridCellMock;
         scenarioGridModel = spy(new ScenarioGridModel(false) {
             {
                 this.simulation = simulationMock;
                 this.eventBus = eventBusMock;
-                this.rows = gridRows;
+                this.rows = GRID_ROWS;
                 this.columns = gridColumns;
             }
 
@@ -231,7 +224,6 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
 
     @Test
     public void duplicateRow() {
-        reset(scenarioGridModel);
         scenarioGridModel.duplicateRow(ROW_INDEX, gridRowMock);
         verify(scenarioGridModel, atLeast(1)).checkSimulation();
         verify(simulationMock, times(1)).cloneScenario(eq(ROW_INDEX), eq(ROW_INDEX + 1));
@@ -240,16 +232,23 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         verify(scenarioGridModel, times(1)).updateIndexColumn();
     }
 
+    @Test
+    public void duplicateColumnValues() {
+        scenarioGridModel.duplicateColumnValues(COLUMN_INDEX, COLUMN_INDEX - 1);
+        verify(scenarioGridModel, times(scenarioGridModel.getRowCount())).getCell(anyInt(), eq(COLUMN_INDEX));
+        verify(scenarioGridModel, times(scenarioGridModel.getRowCount())).setCellValue(anyInt(), eq(COLUMN_INDEX - 1), any());
+        assertTrue(IntStream.range(0, scenarioGridModel.getRowCount())
+                           .allMatch(i -> scenarioGridModel.getCell(i, COLUMN_INDEX).getValue().equals(scenarioGridModel.getCell(i, COLUMN_INDEX).getValue())));
+    }
+
     @Test
     public void insertColumnGridOnly() {
-        reset(scenarioGridModel);
         scenarioGridModel.insertColumnGridOnly(COLUMN_INDEX, gridColumnMock);
         verify(scenarioGridModel, times(1)).checkSimulation();
     }
 
     @Test
     public void insertColumn() {
-        reset(scenarioGridModel);
         scenarioGridModel.insertColumn(COLUMN_INDEX, gridColumnMock);
         verify(scenarioGridModel, times(1)).checkSimulation();
         verify(scenarioGridModel, times(1)).commonAddColumn(eq(COLUMN_INDEX), eq(gridColumnMock));
@@ -259,13 +258,13 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
     public void deleteColumn() {
         scenarioGridModel.deleteColumn(COLUMN_INDEX);
         verify(scenarioGridModel, times(1)).checkSimulation();
+        verify(scenarioGridModel, times(1)).deleteColumn(eq(gridColumnMock));
         verify(simulationMock, times(1)).removeFactMappingByIndex(eq(COLUMN_INDEX));
     }
 
     @Test
     public void updateColumnTypeFalse() {
-        reset(scenarioGridModel);
-        scenarioGridModel.updateColumnProperty(COLUMN_INDEX, gridColumnMock, VALUE, VALUE_CLASS_NAME, false);
+        scenarioGridModel.updateColumnProperty(COLUMN_INDEX, gridColumnMock, MULTIPART_VALUE_ELEMENTS, VALUE_CLASS_NAME, false);
         verify(scenarioGridModel, times(2)).checkSimulation();
         verify(scenarioGridModel, times(1)).deleteColumn(eq(COLUMN_INDEX));
         verify(scenarioGridModel, times(1)).commonAddColumn(eq(COLUMN_INDEX), eq(gridColumnMock), isA(ExpressionIdentifier.class));
@@ -273,8 +272,7 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
 
     @Test
     public void updateColumnTypeTrue() {
-        reset(scenarioGridModel);
-        scenarioGridModel.updateColumnProperty(COLUMN_INDEX, gridColumnMock, VALUE, VALUE_CLASS_NAME, true);
+        scenarioGridModel.updateColumnProperty(COLUMN_INDEX, gridColumnMock, MULTIPART_VALUE_ELEMENTS, VALUE_CLASS_NAME, true);
         verify(scenarioGridModel, atLeast(2)).checkSimulation();
         verify(scenarioGridModel, atLeast(ROW_COUNT - 1)).getCell(anyInt(), eq(COLUMN_INDEX));
         verify(scenarioGridModel, times(1)).deleteColumn(eq(COLUMN_INDEX));
@@ -282,6 +280,15 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         verify(scenarioGridModel, atLeast(ROW_COUNT - 1)).setCellValue(anyInt(), eq(COLUMN_INDEX), isA(ScenarioGridCellValue.class));
     }
 
+    @Test
+    public void replaceColumnTest() {
+        scenarioGridModel.replaceColumn(ROW_INDEX, gridColumnMock);
+        verify(gridColumnMock, times(COLUMN_NUMBER)).getWidth();
+        verify(gridColumnMock, times(COLUMN_NUMBER)).setWidth(anyDouble());
+        verify(scenarioGridModel, times(1)).deleteColumn(eq(ROW_INDEX));
+        verify(scenarioGridModel, times(1)).commonAddColumn(eq(ROW_INDEX), eq(gridColumnMock), isA(ExpressionIdentifier.class));
+    }
+
     @Test
     public void setCellGridOnly() {
         scenarioGridModel.setCellGridOnly(ROW_INDEX, COLUMN_INDEX, gridCellSupplier);
@@ -294,6 +301,30 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         verify(scenarioGridModel, times(1)).setCell(eq(ROW_INDEX), eq(COLUMN_INDEX), eq(gridCellSupplier));
     }
 
+    @Test
+    public void setSelectedColumn() {
+        scenarioGridModel.selectColumn(COLUMN_INDEX);
+        assertEquals(gridColumnMock, scenarioGridModel.getSelectedColumn());
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void setSelectedColumn_NegativeIndex() {
+        int columnIndex = -1;
+        scenarioGridModel.selectColumn(columnIndex);
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void setSelectedColumn_OverflowIndex() {
+        int columnIndex = 7;
+        scenarioGridModel.selectColumn(columnIndex);
+    }
+
+    @Test
+    public void getInstancesCount() {
+        long count = scenarioGridModel.getInstancesCount(FULL_CLASS_NAME);
+        assertEquals(1, count);
+    }
+
     @Test
     public void getInstanceLimits() {
         final GridData.Range retrieved = scenarioGridModel.getInstanceLimits(2);
@@ -313,7 +344,7 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
     public void updateHeader() {
         String newValue = "NEW_VALUE";
         scenarioGridModel.updateHeader(COLUMN_INDEX, 1, newValue); // This is instance header
-        verify(eventBusMock, times(1)).fireEvent(isA(ReloadRightPanelEvent.class));
+        verify(eventBusMock, times(1)).fireEvent(isA(ReloadTestToolsEvent.class));
         reset(eventBusMock);
         scenarioGridModel.updateHeader(COLUMN_INDEX, 2, newValue); // This is property header
         verify(eventBusMock, never()).fireEvent(any());
@@ -327,7 +358,6 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
     @Test
     public void updateFactMappingInstance() {
         final int INDEX = 0;
-        final String VALUE = "VALUE";
         final String ALIAS_1 = "ALIAS_1";
         final String ALIAS_2 = "ALIAS_2";
         FactMapping factMappingReference = mock(FactMapping.class);
@@ -340,44 +370,43 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         when(factMappingReference.getFactAlias()).thenReturn(ALIAS_1);
         when(factMappingToCheck.getFactAlias()).thenReturn(ALIAS_1);
         when(simulationDescriptorMock.getFactMappingByIndex(INDEX)).thenReturn(factMappingToCheck);
-        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
-        verify(informationHeaderMetaDataMock, times(1)).setTitle(eq(VALUE));
-        verify(factMappingToCheck, times(1)).setFactAlias(eq(VALUE));
+        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, MULTIPART_VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
+        verify(informationHeaderMetaDataMock, times(1)).setTitle(eq(MULTIPART_VALUE));
+        verify(factMappingToCheck, times(1)).setFactAlias(eq(MULTIPART_VALUE));
         reset(informationHeaderMetaDataMock);
         reset(factMappingToCheck);
         // Should not execute the if in the first if
         when(factMappingToCheck.getFactAlias()).thenReturn(ALIAS_2);
-        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
-        verify(informationHeaderMetaDataMock, never()).setTitle(eq(VALUE));
-        verify(factMappingToCheck, never()).setFactAlias(eq(VALUE));
+        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, MULTIPART_VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
+        verify(informationHeaderMetaDataMock, never()).setTitle(eq(MULTIPART_VALUE));
+        verify(factMappingToCheck, never()).setFactAlias(eq(MULTIPART_VALUE));
         reset(informationHeaderMetaDataMock);
         reset(factMappingToCheck);
         // Should not execute the if in the first if
         when(factMappingReference.getFactIdentifier()).thenReturn(factIdentifier1);
         when(factMappingToCheck.getFactAlias()).thenReturn(ALIAS_1);
-        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
-        verify(informationHeaderMetaDataMock, never()).setTitle(eq(VALUE));
-        verify(factMappingToCheck, never()).setFactAlias(eq(VALUE));
+        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, MULTIPART_VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
+        verify(informationHeaderMetaDataMock, never()).setTitle(eq(MULTIPART_VALUE));
+        verify(factMappingToCheck, never()).setFactAlias(eq(MULTIPART_VALUE));
         reset(informationHeaderMetaDataMock);
         reset(factMappingToCheck);
         // Should execute the second if
         when(factMappingToCheck.getFactIdentifier()).thenReturn(factIdentifier1);
-        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
-        verify(informationHeaderMetaDataMock, times(1)).setTitle(eq(VALUE));
-        verify(factMappingToCheck, times(1)).setFactAlias(eq(VALUE));
+        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, MULTIPART_VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
+        verify(informationHeaderMetaDataMock, times(1)).setTitle(eq(MULTIPART_VALUE));
+        verify(factMappingToCheck, times(1)).setFactAlias(eq(MULTIPART_VALUE));
         reset(informationHeaderMetaDataMock);
         reset(factMappingToCheck);
         // Should not execute the second if
         when(factMappingToCheck.getFactIdentifier()).thenReturn(factIdentifier2);
-        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
-        verify(informationHeaderMetaDataMock, never()).setTitle(eq(VALUE));
-        verify(factMappingToCheck, never()).setFactAlias(eq(VALUE));
+        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, MULTIPART_VALUE, ScenarioHeaderMetaData.MetadataType.INSTANCE);
+        verify(informationHeaderMetaDataMock, never()).setTitle(eq(MULTIPART_VALUE));
+        verify(factMappingToCheck, never()).setFactAlias(eq(MULTIPART_VALUE));
     }
 
     @Test
     public void updateFactMappingProperty() {
         final int INDEX = 0;
-        final String VALUE = "VALUE";
         final String ALIAS_1 = "ALIAS_1";
         final String ALIAS_2 = "ALIAS_2";
         FactMapping factMappingReference = mock(FactMapping.class);
@@ -391,30 +420,29 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         when(factMappingReference.getFullExpression()).thenReturn(ALIAS_1);
         when(factMappingToCheck.getFullExpression()).thenReturn(ALIAS_1);
         when(simulationDescriptorMock.getFactMappingByIndex(INDEX)).thenReturn(factMappingToCheck);
-        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, VALUE, ScenarioHeaderMetaData.MetadataType.PROPERTY);
-        verify(propertyHeaderMetaDataMock, times(1)).setTitle(eq(VALUE));
-        verify(factMappingToCheck, times(1)).setExpressionAlias(eq(VALUE));
+        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, MULTIPART_VALUE, ScenarioHeaderMetaData.MetadataType.PROPERTY);
+        verify(propertyHeaderMetaDataMock, times(1)).setTitle(eq(MULTIPART_VALUE));
+        verify(factMappingToCheck, times(1)).setExpressionAlias(eq(MULTIPART_VALUE));
         reset(propertyHeaderMetaDataMock);
         reset(factMappingToCheck);
         // Should not execute
         when(factMappingToCheck.getFactAlias()).thenReturn(ALIAS_2);
-        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, VALUE, ScenarioHeaderMetaData.MetadataType.PROPERTY);
-        verify(propertyHeaderMetaDataMock, never()).setTitle(eq(VALUE));
-        verify(factMappingToCheck, never()).setExpressionAlias(eq(VALUE));
+        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, MULTIPART_VALUE, ScenarioHeaderMetaData.MetadataType.PROPERTY);
+        verify(propertyHeaderMetaDataMock, never()).setTitle(eq(MULTIPART_VALUE));
+        verify(factMappingToCheck, never()).setExpressionAlias(eq(MULTIPART_VALUE));
         reset(propertyHeaderMetaDataMock);
         reset(factMappingToCheck);
         // Should not execute
         when(factMappingReference.getFactIdentifier()).thenReturn(factIdentifier1);
         when(factMappingToCheck.getFactAlias()).thenReturn(ALIAS_1);
         when(factMappingToCheck.getFullExpression()).thenReturn(ALIAS_2);
-        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, VALUE, ScenarioHeaderMetaData.MetadataType.PROPERTY);
-        verify(propertyHeaderMetaDataMock, never()).setTitle(eq(VALUE));
-        verify(factMappingToCheck, never()).setExpressionAlias(eq(VALUE));
+        scenarioGridModel.updateFactMapping(simulationDescriptorMock, factMappingReference, INDEX, MULTIPART_VALUE, ScenarioHeaderMetaData.MetadataType.PROPERTY);
+        verify(propertyHeaderMetaDataMock, never()).setTitle(eq(MULTIPART_VALUE));
+        verify(factMappingToCheck, never()).setExpressionAlias(eq(MULTIPART_VALUE));
     }
 
     @Test
     public void commonAddColumn() {
-        reset(scenarioGridModel);
         scenarioGridModel.commonAddColumn(COLUMN_INDEX, gridColumnMock);
         verify(scenarioGridModel, times(0)).checkSimulation();
     }
@@ -429,7 +457,7 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         scenarioGridModel.updateIndexColumn();
         verify(scenarioGridModel, never()).setCellValue(anyInt(), anyInt(), isA(ScenarioGridCellValue.class));
         reset(scenarioGridModel);
-        when(scenarioGridModel.getRowCount()).thenReturn(3);
+        when(scenarioGridModel.getRowCount()).thenReturn(ROW_COUNT);
         int indexColumnPosition = 0;
         gridColumns.add(indexColumnPosition, scenarioIndexGridColumnMock);
         when(scenarioGridModel.getColumns()).thenReturn(gridColumns);
@@ -438,17 +466,27 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
 
     @Test
     public void isSameInstanceHeaderDifferent() {
-        commonIsSameInstanceHeader("TEST", "TOAST", false);
+        commonCheckSameInstanceHeader(CLASS_NAME, "TOAST", false);
     }
 
     @Test
     public void isSameInstanceHeaderEqualWithoutPackage() {
-        commonIsSameInstanceHeader("TEST", "TEST", true);
+        commonCheckSameInstanceHeader(CLASS_NAME, CLASS_NAME, true);
     }
 
     @Test
     public void isSameInstanceHeaderEqualWithPackage() {
-        commonIsSameInstanceHeader("com.something.TEST", "TEST", true);
+        commonCheckSameInstanceHeader(FULL_CLASS_NAME, CLASS_NAME, false);
+    }
+
+    @Test
+    public void isSameInstanceHeader_Different() {
+        isSameInstanceType(CLASS_NAME, "TOAST", false);
+    }
+
+    @Test
+    public void isSameInstanceHeader_Equal() {
+        isSameInstanceType(CLASS_NAME, CLASS_NAME, true);
     }
 
     @Test
@@ -457,8 +495,7 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         scenarioGridModel.refreshErrors();
         verify(gridCellMock, times(expectedCalls)).setErrorMode(eq(true));
 
-        reset(gridCellMock);
-        when(factMappingValueMock.isError()).thenReturn(false);
+        when(factMappingValueMock.getStatus()).thenReturn(FactMappingValueStatus.SUCCESS);
         scenarioGridModel.refreshErrors();
         verify(gridCellMock, times(expectedCalls)).setErrorMode(eq(false));
     }
@@ -467,7 +504,7 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
     public void refreshErrorsRow() {
         int expectedCalls = scenarioGridModel.getColumnCount();
         FactMappingValue factMappingValue = mock(FactMappingValue.class);
-        when(factMappingValue.isError()).thenReturn(true);
+        when(factMappingValue.getStatus()).thenReturn(FactMappingValueStatus.FAILED_WITH_ERROR);
 
         when(scenarioMock.getFactMappingValue(any(), any())).thenReturn(Optional.empty());
         scenarioGridModel.refreshErrorsRow(0);
@@ -479,7 +516,7 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
     }
 
     @Test
-    public void validateInstanceHeaderUpdate() {
+    public void validateInstanceHeaderUpdate() throws Exception {
         commonValidateInstanceHeaderUpdate(1, false, false, false, false);
         commonValidateInstanceHeaderUpdate(1, false, false, true, true);
         commonValidateInstanceHeaderUpdate(1, false, true, false, false);
@@ -487,11 +524,11 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         commonValidateInstanceHeaderUpdate(1, true, false, false, false);
         commonValidateInstanceHeaderUpdate(1, true, false, true, false);
         commonValidateInstanceHeaderUpdate(1, true, true, false, false);
-        commonValidateInstanceHeaderUpdate(1, true, true, true, true);
+        commonValidateInstanceHeaderUpdate(1, true, true, true, false);
     }
 
     @Test
-    public void validatePropertyHeaderUpdate() {
+    public void validatePropertyHeaderUpdate() throws Exception {
         commonValidatePropertyUpdate(1, false, false, false, false);
         commonValidatePropertyUpdate(1, false, false, true, true);
         commonValidatePropertyUpdate(1, false, true, false, false);
@@ -499,40 +536,150 @@ public class ScenarioGridModelTest extends AbstractScenarioSimulationTest {
         commonValidatePropertyUpdate(1, true, false, false, false);
         commonValidatePropertyUpdate(1, true, false, true, false);
         commonValidatePropertyUpdate(1, true, true, false, false);
-        commonValidatePropertyUpdate(1, true, true, true, true);
+        commonValidatePropertyUpdate(1, true, true, true, false);
     }
 
-    private void commonIsSameInstanceHeader(String columnClassName, String value, boolean expected) {
+    private void isSameInstanceType(String columnClassName, String value, boolean expectedResult) {
         FactIdentifier factIdentifierMock = mock(FactIdentifier.class);
-        when(factIdentifierMock.getClassName()).thenReturn(columnClassName);
-        int colIndex = 3;
+        when(factIdentifierMock.getClassNameWithoutPackage()).thenReturn(columnClassName);
         when(factMappingMock.getFactIdentifier()).thenReturn(factIdentifierMock);
-        when(simulationDescriptorMock.getFactMappingByIndex(colIndex)).thenReturn(factMappingMock);
-        boolean retrieved = scenarioGridModel.isSameInstanceHeader(colIndex, value);
-        if (expected) {
-            TestCase.assertTrue(retrieved);
-        } else {
-            assertFalse(retrieved);
-        }
+        when(simulationDescriptorMock.getFactMappingByIndex(COLUMN_INDEX)).thenReturn(factMappingMock);
+        boolean result = scenarioGridModel.isSameInstanceType(COLUMN_INDEX, value);
         verify(simulationMock, times(1)).getSimulationDescriptor();
-        verify(simulationDescriptorMock, times(1)).getFactMappingByIndex(eq(colIndex));
+        verify(simulationDescriptorMock, times(1)).getFactMappingByIndex(eq(COLUMN_INDEX));
+        assertEquals(result, expectedResult);
     }
 
-    private void commonValidateInstanceHeaderUpdate(int columnIndex, boolean isADataType, boolean isSameInstanceHeader, boolean isUnique, boolean expectedValid) {
-        String value = "VALUE";
-        doReturn(isSameInstanceHeader).when(scenarioGridModel).isSameInstanceHeader(columnIndex, value);
-        doReturn(isUnique).when(scenarioGridModel).isUniqueInstanceHeaderTitle(value, columnIndex);
-        boolean retrieved = scenarioGridModel.validateInstanceHeaderUpdate(value, columnIndex, isADataType);
-        assertEquals(retrieved, expectedValid);
+    private void commonCheckSameInstanceHeader(String columnClassName, String value, boolean expected)  {
+        FactIdentifier factIdentifierMock = mock(FactIdentifier.class);
+        when(factIdentifierMock.getClassNameWithoutPackage()).thenReturn(columnClassName);
+        when(factMappingMock.getFactIdentifier()).thenReturn(factIdentifierMock);
+        when(simulationDescriptorMock.getFactMappingByIndex(COLUMN_INDEX)).thenReturn(factMappingMock);
+        try {
+            scenarioGridModel.checkSameInstanceHeader(COLUMN_INDEX, value);
+            verify(scenarioGridModel, times(1)).isSameInstanceType(eq(COLUMN_INDEX), eq(value));
+        } catch (Exception e) {
+            if (expected) {
+                fail("No exception expected, retrieved " + e.getMessage());
+            }
+        }
+    }
+
+    private void commonValidateInstanceHeaderUpdate(int columnIndex, boolean isADataType, boolean isSameInstanceHeader, boolean isUnique, boolean expectedValid) throws Exception {
+        if (isSameInstanceHeader) {
+            doThrow(new IllegalArgumentException("isSameInstanceHeader")).when(scenarioGridModel).checkSameInstanceHeader(columnIndex, MULTIPART_VALUE_ELEMENTS.get(MULTIPART_VALUE_ELEMENTS.size() - 1));
+        } else {
+            doNothing().when(scenarioGridModel).checkSameInstanceHeader(columnIndex, MULTIPART_VALUE_ELEMENTS.get(MULTIPART_VALUE_ELEMENTS.size() - 1));
+        }
+        if (isUnique) {
+            doNothing().when(scenarioGridModel).checkValidAndUniqueInstanceHeaderTitle(MULTIPART_VALUE, columnIndex);
+        } else {
+            doThrow(new IllegalArgumentException("isUnique")).when(scenarioGridModel).checkValidAndUniqueInstanceHeaderTitle(MULTIPART_VALUE, columnIndex);
+        }
+        try {
+            scenarioGridModel.validateInstanceHeaderUpdate(MULTIPART_VALUE, columnIndex, isADataType);
+        } catch (Exception e) {
+            if (expectedValid) {
+                fail("No exception expected, retrieved:  " + e.getMessage());
+            }
+        }
         reset(eventBusMock);
     }
 
-    private void commonValidatePropertyUpdate(int columnIndex, boolean isPropertyType, boolean isSamePropertyHeader, boolean isUnique, boolean expectedValid) {
-        String value = "VALUE";
-        doReturn(isSamePropertyHeader).when(scenarioGridModel).isSamePropertyHeader(columnIndex, value);
-        doReturn(isUnique).when(scenarioGridModel).isUniquePropertyHeaderTitle(value, columnIndex);
-        boolean retrieved = scenarioGridModel.validatePropertyHeaderUpdate(value, columnIndex, isPropertyType);
-        assertEquals(retrieved, expectedValid);
+    private void commonValidatePropertyUpdate(int columnIndex, boolean isPropertyType, boolean isSamePropertyHeader, boolean isUnique, boolean expectedValid) throws Exception {
+        if (isSamePropertyHeader) {
+            doThrow(new IllegalArgumentException("isSamePropertyHeader")).when(scenarioGridModel).checkSamePropertyHeader(columnIndex, MULTIPART_VALUE_ELEMENTS);
+        } else {
+            doNothing().when(scenarioGridModel).checkSamePropertyHeader(columnIndex, MULTIPART_VALUE_ELEMENTS);
+        }
+        if (isUnique) {
+            doNothing().when(scenarioGridModel).checkValidAndUniquePropertyHeaderTitle(MULTIPART_VALUE, columnIndex);
+        } else {
+            doThrow(new IllegalArgumentException("isUnique")).when(scenarioGridModel).checkValidAndUniquePropertyHeaderTitle(MULTIPART_VALUE, columnIndex);
+        }
+        try {
+            scenarioGridModel.validatePropertyHeaderUpdate(MULTIPART_VALUE, columnIndex, isPropertyType);
+        } catch (Exception e) {
+            if (expectedValid) {
+                fail("No exception expected, retrieved:  " + e.getMessage());
+            }
+        }
         reset(eventBusMock);
     }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void checkUniquePropertyHeaderTitle_AssignedLabel() {
+        scenarioGridModel.checkUniquePropertyHeaderTitle(GRID_PROPERTY_TITLE, COLUMN_INDEX);
+    }
+
+    @Test
+    public void resetError() {
+        scenarioGridModel = spy(new ScenarioGridModel(false) {
+            {
+                this.simulation = simulationMock;
+                this.eventBus = eventBusMock;
+                this.rows = GRID_ROWS;
+                this.columns = gridColumns;
+            }
+
+            @Override
+            public void refreshErrors() {
+                //Do nothing
+            }
+
+            @Override
+            public GridCell<?> getCell(final int rowIndex,
+                                       final int columnIndex) {
+                if (rowIndex < 0 || rowIndex > rows.size() - 1) {
+                    return null;
+                }
+                return gridCellMock;
+            }
+        });
+        scenarioGridModel.resetError(ROW_INDEX, COLUMN_INDEX);
+        verify(simulationMock, times(1)).getScenarioByIndex(eq(ROW_INDEX));
+        verify(simulationDescriptorMock, times(1)).getFactMappingByIndex(eq(COLUMN_INDEX));
+        verify(scenarioMock, times(1)).getFactMappingValue(eq(factMappingMock));
+        verify(factMappingValueMock, times(1)).resetStatus();
+        verify(scenarioGridModel, times(1)).refreshErrors();
+    }
+
+    @Test
+    public void synchronizeFactMappingsWidths() {
+        scenarioGridModel.synchronizeFactMappingsWidths();
+        verify(scenarioGridModel, times(gridColumns.size())).synchronizeFactMappingWidth(isA(GridColumn.class));
+    }
+
+    @Test
+    public void synchronizeFactMappingWidth() {
+        when(gridColumnMock.isVisible()).thenReturn(true);
+        scenarioGridModel.synchronizeFactMappingWidth(gridColumnMock);
+        verify(factMappingMock, times(1)).setColumnWidth(eq(gridColumnMock.getWidth()));
+    }
+
+    @Test
+    public void synchronizeFactMappingWidth_NotVisibleColumn() {
+        when(gridColumnMock.isVisible()).thenReturn(false);
+        scenarioGridModel.synchronizeFactMappingWidth(gridColumnMock);
+        verify(factMappingMock, never()).setColumnWidth(any());
+    }
+
+    @Test
+    public void loadFactMappingsWidth_FactMappingWithoutWidth() {
+        when(factMappingMock.getColumnWidth()).thenReturn(null);
+        gridColumns.clear();
+        gridColumns.add(gridColumnMock);
+        scenarioGridModel.loadFactMappingsWidth();
+        verify(gridColumnMock, never()).setWidth(anyDouble());
+    }
+
+    @Test
+    public void loadFactMappingsWidth_FactMappingWithWidth() {
+        when(factMappingMock.getColumnWidth()).thenReturn(54.32);
+        gridColumns.clear();
+        gridColumns.add(gridColumnMock);
+        scenarioGridModel.loadFactMappingsWidth();
+        verify(factMappingMock, never()).setColumnWidth(anyDouble());
+        verify(gridColumnMock, times(1)).setWidth(eq(factMappingMock.getColumnWidth()));
+    }
 }
\ No newline at end of file
